@@ -100,6 +100,16 @@ impl MessageLocator {
         self._current_locale.clone()
     }
 
+    /// Returns the currently loaded locale followed by its fallbacks or empty if no locale is loaded.
+    pub fn current_locale_seq(&self) -> HashSet<Locale> {
+        if let Some(c) = self.current_locale() {
+            let mut r: HashSet<Locale> = hashset![c.clone()];
+            self.enumerate_fallbacks(c.clone(), &mut r);
+            return r;
+        }
+        hashset![]
+    }
+
     /// Attempts to load the specified locale and its fallbacks.
     /// If any resource fails to load, the method returns `false`, otherwise `true`.
     pub async fn update_locale(&mut self, new_locale: Locale) -> bool {
@@ -286,6 +296,8 @@ impl MessageLocator {
 }
 
 impl Clone for MessageLocator {
+    /// Clones the locator, sharing the same
+    /// resources.
     fn clone(&self) -> Self {
         Self {
             _current_locale: self._current_locale.clone(),
